2048
====

2048 is a sliding-block puzzle game by the Italian web developer
Gabriele Cirulli. The goal is to slide numbered tiles on a grid,
combining them to create a tile with a value of 2048.

.. figure:: screenshot.png
   :alt: Screenshot of an in-progress 2048 game

   Screenshot of an in-progress 2048 game



`Download the demo <../../_static/twentyfortyeight.zip>`__.
